### Data Matrix Rectangular Extension

The **Data Matrix Rectangular Extension** symbology is an enhancement to [Data Matrix Rectangular](Data-Matrix-Rectangular) that provides a greater range of symbol dimensions.

Also known as: DMRE.

Variants:

  * [Data Matrix](Data-Matrix) is the standard square variant of the symbology.
  * [Data Matrix Rectangular](Data-Matrix-Rectangular) is the original rectangular variant of Data Matrix that provides a limited range of symbol dimensions.

Standards: ISO/IEC 21471.


#### Data and Options

  * The data field can contain any extended ASCII data. The default interpretation of data by readers is in accordance with ISO/IEC 8859-1. When supported by the receiver characters from other code pages can be encoded using Extended Channel Interpretation (ECI).
  * When the **parse** option is specified, any instances of `^NNN` in the data field are replaced with their equivalent ASCII value. This is useful for specifying unprintable characters.
  * When the **parsefnc** option is specified, non-data function characters can be specified by escape sequences:
    * `^FNC1`: FNC1
    * `^PROG`: PROG - Reader programming
    * `^ECI000000` to `^ECI999999`: ECI indicators
  * Whenever the data field contains suitable input, the encoder will compress ISO/IEC 15434 structured data (internally using the 05 Macro and 06 Macro codewords.)
  * When the **dotty** option is specified the modules are rendered as dots rather than squares. The dot radius can be adjusted using the **inkspread** option.
  * The **columns** and **rows** options are used to specify the size of the symbol.
  * The **version** option can also be used to specify the symbol size, as `version=RxC`. Valid options are _8x18_, _8x32_, _8x48_, _8x64_, _8x80_, _8x96_, _8x120_, _8x144_, _12x26_, _12x36_, _12x64_, _12x88_, _16x36_, _16x48_, _16x64_, _20x36_, _20x44_, _20x64_, _22x48_, _24x48_, _24x64_, _26x40_, _26x48_, _26x64_.
  * If **columns**, **rows** and **version** are unspecified the encoder will default to creating a symbol that is the minimum size to represent the given data.
  * The **raw** option denotes that the data field is providing the input as pre-encoded codewords in `^NNN` format, suitable for direct low-level encoding.
  * _Deprecated: Standard is obsolete._ The **dindmre** option select Data Matrix Rectangular Extension symbols whose dimensions are based on the obsolete DIN standard, rather than the current ISO standard.
    * With `dindmre` the valid version **options** are _8x18_, _8x32_, _8x48_, _8x64_, _12x26_, _12x36_, _12x64_, _16x36_, _16x48_, _16x64_, _24x32_, _24x36_, _24x48_, _24x64_, _26x32_, _26x40_, _26x48_, _26x64_.

#### Examples

A DMRE symbol with a fixed size:

```
Data:    1234
Options: version=8x80
Encoder: datamatrixrectangularextension
```

![](images/datamatrix-4.png)
