### Data Matrix Rectangular

The **Data Matrix Rectangular** symbology is a rectangular variant of [Data Matrix](Data-Matrix).

Variants:

  * [Data Matrix](Data-Matrix) is the standard square variant of the symbology.
  * [Data Matrix Rectangular Extension](Data-Matrix-Rectangular-Extension) is a variant of Data Matrix Rectangular that provides a greater range of symbol dimensions.

Standards: ISO/IEC 16022, ANSI/AIM BC11 - ISS Data Matrix.


#### Data and Options

  * The data field can contain any extended ASCII data. The default interpretation of data by readers is in accordance with ISO/IEC 8859-1. When supported by the receiver characters from other code pages can be encoded using Extended Channel Interpretation (ECI).
  * When the **parse** option is specified, any instances of `^NNN` in the data field are replaced with their equivalent ASCII value. This is useful for specifying unprintable characters.
  * When the **parsefnc** option is specified, non-data function characters can be specified by escape sequences:
    * `^FNC1`: FNC1. _Recommendation: Use [GS1 DataMatrix](GS1-DataMatrix) for encoding GS1 AI syntax data._
    * `^PROG`: PROG - Reader programming
    * `^ECI000000` to `^ECI999999`: ECI indicators
  * Whenever the data field contains suitable input, the encoder will compress ISO/IEC 15434 structured data (internally using the 05 Macro and 06 Macro codewords.)
  * When the **dotty** option is specified the modules are rendered as dots rather than squares. The dot radius can be adjusted using the **inkspread** option.
  * _Deprecated: Use [Data Matrix Rectangular Extension](Data-Matrix-Rectangular-Extension)._ The **dmre** option enables Data Matrix Rectangular Extension symbols based on the ISO/IEC standard, which increases the number of rectangular symbol sizes available.
  * _Deprecated: Standard is obsolete. Use [Data Matrix Rectangular Extension](Data-Matrix-Rectangular-Extension) with the dindmre option._ The **dindmre** option enables Data Matrix Rectangular Extension symbols based on the obsolete DIN standard.
  * The **columns** and **rows** options are used to specify the size of the symbol.
  * The **version** option can also be used to specify the symbol size, as `version=RxC`. Valid options are _8x18_, _8x32_, _12x26_, _12x36_, _16x36_, _16x48_.
  * If **columns**, **rows** and **version** are unspecified the encoder will default to creating a symbol that is the minimum size to represent the given data.
  * The **raw** option denotes that the data field is providing the input as pre-encoded codewords in `^NNN` format, suitable for direct low-level encoding.

#### Examples

A rectangular symbol with a fixed size:

```
Data:    Rectangular
Options: version=16x48
Encoder: datamatrixrectangular
```

![](images/datamatrix-3.png)
