### Data Matrix

The **Data Matrix** symbology is 2D matrix-style barcode that can encode full 256 character extended-ASCII.

Also known as: Data Matrix ECC 200, DataMatrix.

Variants:

  * [Data Matrix Rectangular](Data-Matrix-Rectangular) is a variant of Data Matrix that uses rectangular symbols.
  * [Data Matrix Rectangular Extension](Data-Matrix-Rectangular-Extension) is a variant of Data Matrix Rectangular that provides a greater range of symbol dimensions.
  * [GS1 DataMatrix](GS1-DataMatrix) is a variant of Data Matrix that should be used when encoding data that is in [GS1 Application Identifier standard format](GS1-Application-Identifier-Standard-Format).
  * [HIBC Data Matrix](HIBC-Symbols) is a variant of Data Matrix that should be used when encoding HIBC formatted data.
  * [Royal Mail Mailmark](Mailmark) is a variant of Data Matrix that is used by the Royal Mail postal service on letters and other small mailpieces.

Standards: ISO/IEC 16022, ANSI/AIM BC11 - ISS Data Matrix.


#### Data and Options

  * The data field can contain any extended ASCII data. The default interpretation of data by readers is in accordance with ISO/IEC 8859-1. When supported by the receiver characters from other code pages can be encoded using Extended Channel Interpretation (ECI).
  * When the **parse** option is specified, any instances of `^NNN` in the data field are replaced with their equivalent ASCII value. This is useful for specifying unprintable characters.
  * When the **parsefnc** option is specified, non-data function characters can be specified by escape sequences:
    * `^FNC1`: FNC1. _Recommendation: Use [GS1 DataMatrix](GS1-DataMatrix) for encoding GS1 AI syntax data._
    * `^PROG`: PROG - Reader programming
    * `^ECI000000` to `^ECI999999`: ECI indicators
  * Whenever the data field contains suitable input, the encoder will compress ISO/IEC 15434 structured data (internally using the 05 Macro and 06 Macro codewords.)
  * When the **dotty** option is specified the modules are rendered as dots rather than squares. The dot radius can be adjusted using the **inkspread** option.
  * The **columns** and **rows** options are used to specify the size of the symbol.
  * The **version** option can also be used to specify the symbol size, as `version=RxC`. Valid options are _10x10_, _12x12_, _14x14_, _16x16_, _18x18_, _20x20_, _22x22_, _24x24_, _26x26_, _32x32_, _36x36_, _40x40_, _44x44_, _48x48_, _52x52_, _64x64_, _72x72_, _80x80_, _88x88_, _96x96_, _104x104_, _120x120_, _132x132_, _144x144_
  * If **columns**, **rows** and **version** are unspecified the encoder will default to creating a symbol of the specified **format** that is the minimum size to represent the given data.
  * The **raw** option denotes that the data field is providing the input as pre-encoded codewords in `^NNN` format, suitable for direct low-level encoding.
  * _Deprecated_: The **format** option is used to specify the shape of the symbol, either:
    * `square` (default)
    * `rectangle`: Use [Data Matrix Rectangular](Data-Matrix-Rectangular) for rectangular symbols.
  * _Deprecated: Use [Data Matrix Rectangular Extension](Data-Matrix-Rectangular-Extension)._ The **dmre** option enables Data Matrix Rectangular Extension symbols based on the ISO/IEC standard, which increases the number of rectangular symbol sizes available.
  * _Deprecated: Use [Data Matrix Rectangular Extension](Data-Matrix-Rectangular-Extension) with dimdmre option._ The **dindmre** option enables Data Matrix Rectangular Extension symbols based on the obsolete DIN standard.
  * _Deprecated: For internal use._ The **mailmark** option signifies the requirement to use Mailmark-specific encoding.

#### Examples

Identical symbols, automatically sized, the latter showing use of the parse option:

```
Data:    This is Data Matrix
Options: 
Encoder: datamatrix
```

```
Data:    This is ^068ata Matrix
Options: parse
Encoder: datamatrix
```

![](images/datamatrix-1.png)

Identical symbols with a fixed size:

```
Data:    Fixed size
Options: version=48x48
Encoder: datamatrix
```

```
Data:    Fixed size
Options: rows=48 columns=48
Encoder: datamatrix
```

![](images/datamatrix-2.png)

A rectangular symbol with a fixed size:

```
Data:    Rectangular
Options: format=rectangle version=16x48
Encoder: datamatrix
```

![](images/datamatrix-3.png)

An advanced use containing "hidden data" in the padding codewords as used by some non-standard, "high-security" applications. The technique works by filling the symbol using raw codewords formed from the standard data immediately followed by the non-standard padding data beginning with `^129`:

```
Data:    ^066^067^068^142^052^129^161^056^206^101^251^147
Options: version=16x16 raw
Encoder: datamatrix
```
