### GS1-128

**GS1-128** is an implementation of the [Code 128](Code-128) barcode symbology which carries [GS1 formatted](GS1-Application-Identifier-Standard-Format) data, including a GTIN-14.

Also known as: UCC/EAN-128, EAN-128, UCC-128.

Variants:

  * [GS1-128 Composite](GS1-Composite-Symbols) is a variant of GS1-128 that should be used when a CC-A, CC-B or CC-C GS1 composite 2D component is required.
  * [EAN-14](EAN-14) is a variant of GS1-128 that should be used when encoding a lone fourteen-digit GTIN.
  * [SSCC-18](SSCC-18) is a variant of GS1-128 that should be used when encoding a lone eighteen-digit SSCC.

Standards: ISO/IEC 15417, ANSI/AIM BC4-1999 ISS, BS EN 799, GS1 General Specifications.

#### Data and Options

  * The data field input is provided in [GS1 Application Identifier standard format](GS1-Application-Identifier-Standard-Format).
  * Note that it is not necessary to specify _FNC1_ characters since the encoder will insert these automatically where necessary.
  * _Deprecated._ The **dontlint** option disables GS1 Application Identifier syntax validation allowing images to be generated for input that does not comply with GS1 standards.
  * _Deprecated: For internal use._ The **linkagea** option specifies that the symbol includes a _CC-A_ or _CC-B_ GS1 composite 2D component.
  * _Deprecated: For internal use._ The **linkagec** option specifies that the symbol includes a _CC-C_ GS1 composite 2D component.

#### Examples

GTIN _95012345678903_; Weight _0.123kg_:

```
Data:    (01)95012345678903(3103)000123
Options: includetext
Encoder: gs1-128
```

![](images/ean128-1.png)

GTIN _0061414199996_; Expiration date _1st Jan 2010_; Batch _123ABC_; Serial _1234567890_:

```
Data:    (01)0061414199996(17)100101(10)123ABC(21)1234567890
Options: includetext
Encoder: gs1-128
```

![](images/ean128-2.png)
