### QR Code

The **QR Code** symbology is a 2D matrix-style barcode symbology that can encode full 256 character extended-ASCII.

Also known as: Quick Response Code.

Variants:

  * [Micro QR Code](Micro-QR-Code) is a small QR Code that is used in applications that require a small symbol space.
  * [GS1 QR Code](GS1-QR-Code) is a variant of Data Matrix that should be used when encoding data that is in [GS1 Application Identifier standard format](GS1-Application-Identifier-Standard-Format).
  * [HIBC QR Code](HIBC-Symbols) is a variant of QR Code that should be used when encoding HIBC formatted data.
  * [Swiss QR Code](Swiss-QR-Code) is an variant of the QR Code for use with the QR-bill application supporting Swiss payments.

Standards: ISO/IEC 18004, JIS X 0510, ITS - QR Code, AIM ISS - QR Code.

#### Data and Options

  * The data field can contain any extended ASCII data. The default interpretation of data by readers is in accordance with ISO/IEC 8859-1. When supported by the receiver characters from other code pages can be encoded using Extended Channel Interpretation (ECI).
  * When the **parse** option is specified, any instances of `^NNN` in the data field are replaced with their equivalent ASCII value, useful for specifying unprintable characters.
  * When the **parsefnc** option is specified, non-data function characters can be specified by escape sequences:
    * `^FNC1`: FNC1. _Recommendation: Use [GS1 QR Code](GS1-QR-Code) for encoding GS1 AI syntax data._
    * `^ECI000000` to `^ECI999999`: ECI indicators
  * The **eclevel** option is used to specify the error correction level:
    * `eclevel=L` - Low
    * `eclevel=M` - Medium (default)
    * `eclevel=Q` - Quality
    * `eclevel=H` - High
  * The **version** option is used to specify the size of the symbol, 1 to 40.
  * If unspecified the encoder will select the version of the symbol that is the minimum size to represent the given data at the selected error correction level.
  * _Deprecated_: The **format** option is used to specify the symbol type, either:
    * `full` (default)
    * `micro`: Use [Micro QR Code](Micro-QR-Code) for Micro QR Code symbols.
    * `rmqr`: The standard is still in draft.


#### Examples

```
Data:    QR Code
Options: 
Encoder: qrcode
```

```
Data:    QR ^067ode
Options: parse
Encoder: qrcode
```

![](images/qrcode-1.png)

```
Data:    QR CODE 1234
Options: version=10 eclevel=Q
Encoder: qrcode
```

![](images/qrcode-2.png)

